@@ -1,5 +1,5 @@
 #  Pyrogram - Telegram MTProto API Client Library for Python
-#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
+#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
 #
 #  This file is part of Pyrogram.
 #
@@ -18,12 +18,19 @@
 
 import asyncio
 import logging
-from signal import signal, SIGINT, SIGTERM, SIGABRT
+import signal
+from signal import signal as signal_fn, SIGINT, SIGTERM, SIGABRT
 
 log = logging.getLogger(__name__)
 
 is_idling = False
 
+# Signal number to name
+signals = {
+    k: v for v, k in signal.__dict__.items()
+    if v.startswith("SIG") and not v.startswith("SIG_")
+}
+
 
 async def idle():
     """Block the main script execution until a signal is received.
@@ -34,45 +41,46 @@ async def idle():
     It is useful for event-driven application only, that are, applications which react upon incoming Telegram
     updates through handlers, rather than executing a set of methods sequentially.
 
-    The way Pyrogram works, it will keep your handlers in a pool of worker threads, which are executed concurrently
-    outside the main thread; calling idle() will ensure the client(s) will be kept alive by not letting the main
-    script to end, until you decide to quit.
-
     Once a signal is received (e.g.: from CTRL+C) the function will terminate and your main script will continue.
     Don't forget to call :meth:`~pyrogram.Client.stop` for each running client before the script ends.
 
     Example:
         .. code-block:: python
-            :emphasize-lines: 13
 
+            import asyncio
             from pyrogram import Client, idle
 
-            app1 = Client("account1")
-            app2 = Client("account2")
-            app3 = Client("account3")
 
-            ...  # Set handlers up
+            async def main():
+                apps = [
+                    Client("account1"),
+                    Client("account2"),
+                    Client("account3")
+                ]
 
-            app1.start()
-            app2.start()
-            app3.start()
+                ...  # Set up handlers
 
-            idle()
+                for app in apps:
+                    await app.start()
 
-            app1.stop()
-            app2.stop()
-            app3.stop()
+                await idle()
+
+                for app in apps:
+                    await app.stop()
+
+
+            asyncio.run(main())
     """
     global is_idling
 
-    def signal_handler(_, __):
+    def signal_handler(signum, __):
         global is_idling
 
-        logging.info("Stop signal received ({}). Exiting...".format(_))
+        logging.info(f"Stop signal received ({signals[signum]}). Exiting...")
         is_idling = False
 
     for s in (SIGINT, SIGTERM, SIGABRT):
-        signal(s, signal_handler)
+        signal_fn(s, signal_handler)
 
     is_idling = True
 
